.. _recipe_asr.bader:

asr.bader
=========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.bader`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.bader.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.bader

or as a python module

.. code-block:: console

   $ python -m asr.bader

Detailed description
--------------------
Bader charges analysis.

Steps
-----


asr.bader
^^^^^^^^^
.. autofunction:: asr.bader.main
   